# Pavilion

We sometimes present the Software Gardening Almanack at events, which we want to share with you under this pavilion.

## OSSci Monthly Call Jan 2025

The [OpenSource.science (OSSci)](https://www.opensource.science/) [Map of Open Source (MOSS)](https://www.opensource.science/moss) interest group invited us to present on the Almanack on 1/13/2025.

Please see the [presentation recording](https://youtu.be/b0sZWTl5Fsg?si=xGxYFA8SfbV4wBYB&t=506) or <a>slides below<a href="../_static/OSSci Monthly Call Jan 2025 - Software_Gardening_Almanack.pdf"> as a reference to this presentation.

<iframe src="../_static/OSSci Monthly Call Jan 2025 - Software_Gardening_Almanack.pdf" width="100%" height="600px"></iframe>
